From 224cb1db7244e406e523d17c147230d3022b09e0 Mon Sep 17 00:00:00 2001
From: Christopher James Halse Rogers <raof@ubuntu.com>
Date: Tue, 9 Feb 2010 15:50:31 +1100
Subject: [PATCH 2/2] Add -X handling to exclude directories from the assembly search

---
 dh_clideps |   22 ++++++++++++++++++++++
 1 files changed, 22 insertions(+), 0 deletions(-)

diff --git a/dh_clideps b/dh_clideps
index d748f96..df3f345 100755
--- a/dh_clideps
+++ b/dh_clideps
@@ -65,6 +65,12 @@ paths will be made absolute for the benefit of monodis.
 Note that the directory given should be the complete or relative path to a directory that contains
 the library. See example below.
 
+=item B<-X>path B<--exclude=>path
+
+Paths to exclude from the .dll/.exe search.  Assemblies in these paths or their subdirectories
+will not be searched for dependencies, and assemblies missing references will not cause dh_clideps 
+to fail.
+
 =item B<internal-mono>                             
 
 Uses the mono runtime in . (used for bootstrapping mono packages)  
@@ -84,6 +90,10 @@ or
   (MONO_GAC_PREFIX example)
   dh_clideps -l debian/tmp/usr
 
+Suppose your source package libquux1.0-cil also ships some examples in /usr/share, and you don't
+want to pull in those dependencies.
+  dh_clideps -X/usr/share
+
 =cut
 
 # gar, debhelper 7.1 defines -d for all scripts already :(
@@ -228,6 +238,12 @@ foreach my $package (@{$dh{DOPACKAGES}}) {
                recommends => [],
                suggests => [] );
   my $found_exe = 0;
+
+  use File::Spec;
+  my @exclude_dirs = ();
+  foreach(@{$dh{EXCLUDE}}) {
+      push(@exclude_dirs, File::Spec->catdir($tmp, $_));
+  }
   $needs_net_1_0 = 0;
   $needs_net_2_0 = 0;
   $needs_net_2_1 = 0;
@@ -245,6 +261,12 @@ foreach my $package (@{$dh{DOPACKAGES}}) {
       $found_exe = 1;
     }
 
+    foreach(@exclude_dirs) {
+	if($File::Find::dir =~ m/^$_/) {
+	    verbose_print("Excluding module $file from dir $File::Find::dir");
+	    return;
+	}
+    }
     verbose_print("Package: $package Assembly: $file");
         
     my %shlibRefs = resolveShlibRefs($package, $file);
-- 
1.6.6.1

